Documentation
¶
Index ¶
- Variables
- func RegisterMediaServiceServer(s grpc.ServiceRegistrar, srv MediaServiceServer)
- type Gallery
- func (*Gallery) Descriptor() ([]byte, []int)deprecated
- func (x *Gallery) GetId() *v1.UUID
- func (x *Gallery) GetName() string
- func (x *Gallery) GetStacks() []*Stack
- func (*Gallery) ProtoMessage()
- func (x *Gallery) ProtoReflect() protoreflect.Message
- func (x *Gallery) Reset()
- func (x *Gallery) String() string
- type LookupGalleryStackByNameReq
- func (*LookupGalleryStackByNameReq) Descriptor() ([]byte, []int)deprecated
- func (x *LookupGalleryStackByNameReq) GetGalleryId() *v1.UUID
- func (x *LookupGalleryStackByNameReq) GetName() string
- func (*LookupGalleryStackByNameReq) ProtoMessage()
- func (x *LookupGalleryStackByNameReq) ProtoReflect() protoreflect.Message
- func (x *LookupGalleryStackByNameReq) Reset()
- func (x *LookupGalleryStackByNameReq) String() string
- type MediaServiceClient
- type MediaServiceServer
- type MediaService_ReplaceDocumentClient
- type MediaService_ReplaceDocumentServer
- type MediaService_ReplaceImageClient
- type MediaService_ReplaceImageServer
- type MediaService_UploadDocumentClient
- type MediaService_UploadDocumentServer
- type MediaService_UploadImageClient
- type MediaService_UploadImageServer
- type ReplaceDocumentReq
- func (*ReplaceDocumentReq) Descriptor() ([]byte, []int)deprecated
- func (x *ReplaceDocumentReq) GetChunk() []byte
- func (x *ReplaceDocumentReq) GetMetadata() *ReplaceDocumentReq_ReplaceDocumentMetadata
- func (m *ReplaceDocumentReq) GetReplaceData() isReplaceDocumentReq_ReplaceData
- func (*ReplaceDocumentReq) ProtoMessage()
- func (x *ReplaceDocumentReq) ProtoReflect() protoreflect.Message
- func (x *ReplaceDocumentReq) Reset()
- func (x *ReplaceDocumentReq) String() string
- type ReplaceDocumentReq_Chunk
- type ReplaceDocumentReq_Metadata
- type ReplaceDocumentReq_ReplaceDocumentMetadata
- func (*ReplaceDocumentReq_ReplaceDocumentMetadata) Descriptor() ([]byte, []int)deprecated
- func (x *ReplaceDocumentReq_ReplaceDocumentMetadata) GetDocumentId() *v1.UUID
- func (x *ReplaceDocumentReq_ReplaceDocumentMetadata) GetShelfId() *v1.UUID
- func (*ReplaceDocumentReq_ReplaceDocumentMetadata) ProtoMessage()
- func (x *ReplaceDocumentReq_ReplaceDocumentMetadata) ProtoReflect() protoreflect.Message
- func (x *ReplaceDocumentReq_ReplaceDocumentMetadata) Reset()
- func (x *ReplaceDocumentReq_ReplaceDocumentMetadata) String() string
- type ReplaceImageReq
- func (*ReplaceImageReq) Descriptor() ([]byte, []int)deprecated
- func (x *ReplaceImageReq) GetChunk() []byte
- func (x *ReplaceImageReq) GetMetadata() *ReplaceImageReq_ReplaceImageMetadata
- func (m *ReplaceImageReq) GetReplaceData() isReplaceImageReq_ReplaceData
- func (*ReplaceImageReq) ProtoMessage()
- func (x *ReplaceImageReq) ProtoReflect() protoreflect.Message
- func (x *ReplaceImageReq) Reset()
- func (x *ReplaceImageReq) String() string
- type ReplaceImageReq_Chunk
- type ReplaceImageReq_Metadata
- type ReplaceImageReq_ReplaceImageMetadata
- func (*ReplaceImageReq_ReplaceImageMetadata) Descriptor() ([]byte, []int)deprecated
- func (x *ReplaceImageReq_ReplaceImageMetadata) GetGalleryId() *v1.UUID
- func (x *ReplaceImageReq_ReplaceImageMetadata) GetStackId() *v1.UUID
- func (*ReplaceImageReq_ReplaceImageMetadata) ProtoMessage()
- func (x *ReplaceImageReq_ReplaceImageMetadata) ProtoReflect() protoreflect.Message
- func (x *ReplaceImageReq_ReplaceImageMetadata) Reset()
- func (x *ReplaceImageReq_ReplaceImageMetadata) String() string
- type Shelf
- func (*Shelf) Descriptor() ([]byte, []int)deprecated
- func (x *Shelf) GetDocuments() []*ShelfDocument
- func (x *Shelf) GetId() *v1.UUID
- func (x *Shelf) GetName() string
- func (*Shelf) ProtoMessage()
- func (x *Shelf) ProtoReflect() protoreflect.Message
- func (x *Shelf) Reset()
- func (x *Shelf) String() string
- type ShelfDocument
- func (*ShelfDocument) Descriptor() ([]byte, []int)deprecated
- func (x *ShelfDocument) GetDocument() *StorageDocument
- func (x *ShelfDocument) GetId() *v1.UUID
- func (x *ShelfDocument) GetUniqueName() string
- func (*ShelfDocument) ProtoMessage()
- func (x *ShelfDocument) ProtoReflect() protoreflect.Message
- func (x *ShelfDocument) Reset()
- func (x *ShelfDocument) String() string
- type SortGalleryReq
- func (*SortGalleryReq) Descriptor() ([]byte, []int)deprecated
- func (x *SortGalleryReq) GetId() *v1.UUID
- func (x *SortGalleryReq) GetSorting() []*v1.UUID
- func (*SortGalleryReq) ProtoMessage()
- func (x *SortGalleryReq) ProtoReflect() protoreflect.Message
- func (x *SortGalleryReq) Reset()
- func (x *SortGalleryReq) String() string
- type Stack
- type StackImage
- func (*StackImage) Descriptor() ([]byte, []int)deprecated
- func (x *StackImage) GetImage() *StorageImage
- func (x *StackImage) GetOriginal() bool
- func (x *StackImage) GetSize() string
- func (*StackImage) ProtoMessage()
- func (x *StackImage) ProtoReflect() protoreflect.Message
- func (x *StackImage) Reset()
- func (x *StackImage) String() string
- type StorageDocument
- type StorageFile
- func (*StorageFile) Descriptor() ([]byte, []int)deprecated
- func (x *StorageFile) GetDisk() string
- func (x *StorageFile) GetFilesize() int64
- func (x *StorageFile) GetName() string
- func (x *StorageFile) GetPath() string
- func (x *StorageFile) GetTags() []string
- func (*StorageFile) ProtoMessage()
- func (x *StorageFile) ProtoReflect() protoreflect.Message
- func (x *StorageFile) Reset()
- func (x *StorageFile) String() string
- type StorageImage
- func (*StorageImage) Descriptor() ([]byte, []int)deprecated
- func (x *StorageImage) GetFile() *StorageFile
- func (x *StorageImage) GetHeight() int64
- func (x *StorageImage) GetWidth() int64
- func (*StorageImage) ProtoMessage()
- func (x *StorageImage) ProtoReflect() protoreflect.Message
- func (x *StorageImage) Reset()
- func (x *StorageImage) String() string
- type UnimplementedMediaServiceServer
- func (UnimplementedMediaServiceServer) FetchGallery(context.Context, *v1.UUID) (*Gallery, error)
- func (UnimplementedMediaServiceServer) FetchShelf(context.Context, *v1.UUID) (*Shelf, error)
- func (UnimplementedMediaServiceServer) LookupGalleryByName(context.Context, *v1.NameLookup) (*v1.LookupResp, error)
- func (UnimplementedMediaServiceServer) LookupGalleryStackByName(context.Context, *LookupGalleryStackByNameReq) (*v1.LookupResp, error)
- func (UnimplementedMediaServiceServer) LookupShelfByName(context.Context, *v1.NameLookup) (*v1.LookupResp, error)
- func (UnimplementedMediaServiceServer) ReplaceDocument(MediaService_ReplaceDocumentServer) error
- func (UnimplementedMediaServiceServer) ReplaceImage(MediaService_ReplaceImageServer) error
- func (UnimplementedMediaServiceServer) SortGallery(context.Context, *SortGalleryReq) (*emptypb.Empty, error)
- func (UnimplementedMediaServiceServer) UploadDocument(MediaService_UploadDocumentServer) error
- func (UnimplementedMediaServiceServer) UploadImage(MediaService_UploadImageServer) error
- type UnsafeMediaServiceServer
- type UploadDocumentReq
- func (*UploadDocumentReq) Descriptor() ([]byte, []int)deprecated
- func (x *UploadDocumentReq) GetChunk() []byte
- func (x *UploadDocumentReq) GetMetadata() *UploadDocumentReq_UploadDocumentMetadata
- func (m *UploadDocumentReq) GetUploadData() isUploadDocumentReq_UploadData
- func (*UploadDocumentReq) ProtoMessage()
- func (x *UploadDocumentReq) ProtoReflect() protoreflect.Message
- func (x *UploadDocumentReq) Reset()
- func (x *UploadDocumentReq) String() string
- type UploadDocumentReq_Chunk
- type UploadDocumentReq_Metadata
- type UploadDocumentReq_UploadDocumentMetadata
- func (*UploadDocumentReq_UploadDocumentMetadata) Descriptor() ([]byte, []int)deprecated
- func (x *UploadDocumentReq_UploadDocumentMetadata) GetDisk() string
- func (x *UploadDocumentReq_UploadDocumentMetadata) GetName() string
- func (x *UploadDocumentReq_UploadDocumentMetadata) GetPath() string
- func (x *UploadDocumentReq_UploadDocumentMetadata) GetShelfId() *v1.UUID
- func (x *UploadDocumentReq_UploadDocumentMetadata) GetUniqueName() string
- func (*UploadDocumentReq_UploadDocumentMetadata) ProtoMessage()
- func (x *UploadDocumentReq_UploadDocumentMetadata) ProtoReflect() protoreflect.Message
- func (x *UploadDocumentReq_UploadDocumentMetadata) Reset()
- func (x *UploadDocumentReq_UploadDocumentMetadata) String() string
- type UploadImageReq
- func (*UploadImageReq) Descriptor() ([]byte, []int)deprecated
- func (x *UploadImageReq) GetChunk() []byte
- func (x *UploadImageReq) GetMetadata() *UploadImageReq_UploadImageMetadata
- func (m *UploadImageReq) GetUploadData() isUploadImageReq_UploadData
- func (*UploadImageReq) ProtoMessage()
- func (x *UploadImageReq) ProtoReflect() protoreflect.Message
- func (x *UploadImageReq) Reset()
- func (x *UploadImageReq) String() string
- type UploadImageReq_Chunk
- type UploadImageReq_Metadata
- type UploadImageReq_UploadImageMetadata
- func (*UploadImageReq_UploadImageMetadata) Descriptor() ([]byte, []int)deprecated
- func (x *UploadImageReq_UploadImageMetadata) GetDisk() string
- func (x *UploadImageReq_UploadImageMetadata) GetGalleryId() *v1.UUID
- func (x *UploadImageReq_UploadImageMetadata) GetName() string
- func (x *UploadImageReq_UploadImageMetadata) GetPath() string
- func (*UploadImageReq_UploadImageMetadata) ProtoMessage()
- func (x *UploadImageReq_UploadImageMetadata) ProtoReflect() protoreflect.Message
- func (x *UploadImageReq_UploadImageMetadata) Reset()
- func (x *UploadImageReq_UploadImageMetadata) String() string
Constants ¶
This section is empty.
Variables ¶
var File_media_proto protoreflect.FileDescriptor
var MediaService_ServiceDesc = grpc.ServiceDesc{ ServiceName: "nicecms.media.v1.MediaService", HandlerType: (*MediaServiceServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "LookupShelfByName", Handler: _MediaService_LookupShelfByName_Handler, }, { MethodName: "FetchShelf", Handler: _MediaService_FetchShelf_Handler, }, { MethodName: "LookupGalleryByName", Handler: _MediaService_LookupGalleryByName_Handler, }, { MethodName: "LookupGalleryStackByName", Handler: _MediaService_LookupGalleryStackByName_Handler, }, { MethodName: "FetchGallery", Handler: _MediaService_FetchGallery_Handler, }, { MethodName: "SortGallery", Handler: _MediaService_SortGallery_Handler, }, }, Streams: []grpc.StreamDesc{ { StreamName: "UploadDocument", Handler: _MediaService_UploadDocument_Handler, ClientStreams: true, }, { StreamName: "ReplaceDocument", Handler: _MediaService_ReplaceDocument_Handler, ClientStreams: true, }, { StreamName: "UploadImage", Handler: _MediaService_UploadImage_Handler, ClientStreams: true, }, { StreamName: "ReplaceImage", Handler: _MediaService_ReplaceImage_Handler, ClientStreams: true, }, }, Metadata: "media.proto", }
MediaService_ServiceDesc is the grpc.ServiceDesc for MediaService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterMediaServiceServer ¶
func RegisterMediaServiceServer(s grpc.ServiceRegistrar, srv MediaServiceServer)
Types ¶
type Gallery ¶
type Gallery struct {
Id *v1.UUID `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
Stacks []*Stack `protobuf:"bytes,3,rep,name=stacks,proto3" json:"stacks,omitempty"`
// contains filtered or unexported fields
}
func (*Gallery) Descriptor
deprecated
func (*Gallery) ProtoMessage ¶
func (*Gallery) ProtoMessage()
func (*Gallery) ProtoReflect ¶
func (x *Gallery) ProtoReflect() protoreflect.Message
type LookupGalleryStackByNameReq ¶
type LookupGalleryStackByNameReq struct {
GalleryId *v1.UUID `protobuf:"bytes,1,opt,name=galleryId,proto3" json:"galleryId,omitempty"`
Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
// contains filtered or unexported fields
}
func (*LookupGalleryStackByNameReq) Descriptor
deprecated
func (*LookupGalleryStackByNameReq) Descriptor() ([]byte, []int)
Deprecated: Use LookupGalleryStackByNameReq.ProtoReflect.Descriptor instead.
func (*LookupGalleryStackByNameReq) GetGalleryId ¶
func (x *LookupGalleryStackByNameReq) GetGalleryId() *v1.UUID
func (*LookupGalleryStackByNameReq) GetName ¶
func (x *LookupGalleryStackByNameReq) GetName() string
func (*LookupGalleryStackByNameReq) ProtoMessage ¶
func (*LookupGalleryStackByNameReq) ProtoMessage()
func (*LookupGalleryStackByNameReq) ProtoReflect ¶
func (x *LookupGalleryStackByNameReq) ProtoReflect() protoreflect.Message
func (*LookupGalleryStackByNameReq) Reset ¶
func (x *LookupGalleryStackByNameReq) Reset()
func (*LookupGalleryStackByNameReq) String ¶
func (x *LookupGalleryStackByNameReq) String() string
type MediaServiceClient ¶
type MediaServiceClient interface {
LookupShelfByName(ctx context.Context, in *v1.NameLookup, opts ...grpc.CallOption) (*v1.LookupResp, error)
UploadDocument(ctx context.Context, opts ...grpc.CallOption) (MediaService_UploadDocumentClient, error)
ReplaceDocument(ctx context.Context, opts ...grpc.CallOption) (MediaService_ReplaceDocumentClient, error)
FetchShelf(ctx context.Context, in *v1.UUID, opts ...grpc.CallOption) (*Shelf, error)
LookupGalleryByName(ctx context.Context, in *v1.NameLookup, opts ...grpc.CallOption) (*v1.LookupResp, error)
LookupGalleryStackByName(ctx context.Context, in *LookupGalleryStackByNameReq, opts ...grpc.CallOption) (*v1.LookupResp, error)
UploadImage(ctx context.Context, opts ...grpc.CallOption) (MediaService_UploadImageClient, error)
ReplaceImage(ctx context.Context, opts ...grpc.CallOption) (MediaService_ReplaceImageClient, error)
FetchGallery(ctx context.Context, in *v1.UUID, opts ...grpc.CallOption) (*Gallery, error)
SortGallery(ctx context.Context, in *SortGalleryReq, opts ...grpc.CallOption) (*emptypb.Empty, error)
}
MediaServiceClient is the client API for MediaService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
func NewMediaServiceClient ¶
func NewMediaServiceClient(cc grpc.ClientConnInterface) MediaServiceClient
type MediaServiceServer ¶
type MediaServiceServer interface {
LookupShelfByName(context.Context, *v1.NameLookup) (*v1.LookupResp, error)
UploadDocument(MediaService_UploadDocumentServer) error
ReplaceDocument(MediaService_ReplaceDocumentServer) error
FetchShelf(context.Context, *v1.UUID) (*Shelf, error)
LookupGalleryByName(context.Context, *v1.NameLookup) (*v1.LookupResp, error)
LookupGalleryStackByName(context.Context, *LookupGalleryStackByNameReq) (*v1.LookupResp, error)
UploadImage(MediaService_UploadImageServer) error
ReplaceImage(MediaService_ReplaceImageServer) error
FetchGallery(context.Context, *v1.UUID) (*Gallery, error)
SortGallery(context.Context, *SortGalleryReq) (*emptypb.Empty, error)
// contains filtered or unexported methods
}
MediaServiceServer is the server API for MediaService service. All implementations must embed UnimplementedMediaServiceServer for forward compatibility
type MediaService_ReplaceDocumentClient ¶
type MediaService_ReplaceDocumentClient interface {
Send(*ReplaceDocumentReq) error
CloseAndRecv() (*ShelfDocument, error)
grpc.ClientStream
}
type MediaService_ReplaceDocumentServer ¶
type MediaService_ReplaceDocumentServer interface {
SendAndClose(*ShelfDocument) error
Recv() (*ReplaceDocumentReq, error)
grpc.ServerStream
}
type MediaService_ReplaceImageClient ¶
type MediaService_ReplaceImageClient interface {
Send(*ReplaceImageReq) error
CloseAndRecv() (*Stack, error)
grpc.ClientStream
}
type MediaService_ReplaceImageServer ¶
type MediaService_ReplaceImageServer interface {
SendAndClose(*Stack) error
Recv() (*ReplaceImageReq, error)
grpc.ServerStream
}
type MediaService_UploadDocumentClient ¶
type MediaService_UploadDocumentClient interface {
Send(*UploadDocumentReq) error
CloseAndRecv() (*ShelfDocument, error)
grpc.ClientStream
}
type MediaService_UploadDocumentServer ¶
type MediaService_UploadDocumentServer interface {
SendAndClose(*ShelfDocument) error
Recv() (*UploadDocumentReq, error)
grpc.ServerStream
}
type MediaService_UploadImageClient ¶
type MediaService_UploadImageClient interface {
Send(*UploadImageReq) error
CloseAndRecv() (*Stack, error)
grpc.ClientStream
}
type MediaService_UploadImageServer ¶
type MediaService_UploadImageServer interface {
SendAndClose(*Stack) error
Recv() (*UploadImageReq, error)
grpc.ServerStream
}
type ReplaceDocumentReq ¶
type ReplaceDocumentReq struct {
// Types that are assignable to ReplaceData:
// *ReplaceDocumentReq_Metadata
// *ReplaceDocumentReq_Chunk
ReplaceData isReplaceDocumentReq_ReplaceData `protobuf_oneof:"replace_data"`
// contains filtered or unexported fields
}
func (*ReplaceDocumentReq) Descriptor
deprecated
func (*ReplaceDocumentReq) Descriptor() ([]byte, []int)
Deprecated: Use ReplaceDocumentReq.ProtoReflect.Descriptor instead.
func (*ReplaceDocumentReq) GetChunk ¶
func (x *ReplaceDocumentReq) GetChunk() []byte
func (*ReplaceDocumentReq) GetMetadata ¶
func (x *ReplaceDocumentReq) GetMetadata() *ReplaceDocumentReq_ReplaceDocumentMetadata
func (*ReplaceDocumentReq) GetReplaceData ¶
func (m *ReplaceDocumentReq) GetReplaceData() isReplaceDocumentReq_ReplaceData
func (*ReplaceDocumentReq) ProtoMessage ¶
func (*ReplaceDocumentReq) ProtoMessage()
func (*ReplaceDocumentReq) ProtoReflect ¶
func (x *ReplaceDocumentReq) ProtoReflect() protoreflect.Message
func (*ReplaceDocumentReq) Reset ¶
func (x *ReplaceDocumentReq) Reset()
func (*ReplaceDocumentReq) String ¶
func (x *ReplaceDocumentReq) String() string
type ReplaceDocumentReq_Chunk ¶
type ReplaceDocumentReq_Chunk struct {
Chunk []byte `protobuf:"bytes,2,opt,name=chunk,proto3,oneof"`
}
type ReplaceDocumentReq_Metadata ¶
type ReplaceDocumentReq_Metadata struct {
Metadata *ReplaceDocumentReq_ReplaceDocumentMetadata `protobuf:"bytes,1,opt,name=metadata,proto3,oneof"`
}
type ReplaceDocumentReq_ReplaceDocumentMetadata ¶
type ReplaceDocumentReq_ReplaceDocumentMetadata struct {
ShelfId *v1.UUID `protobuf:"bytes,1,opt,name=shelfId,proto3" json:"shelfId,omitempty"`
DocumentId *v1.UUID `protobuf:"bytes,2,opt,name=documentId,proto3" json:"documentId,omitempty"`
// contains filtered or unexported fields
}
func (*ReplaceDocumentReq_ReplaceDocumentMetadata) Descriptor
deprecated
func (*ReplaceDocumentReq_ReplaceDocumentMetadata) Descriptor() ([]byte, []int)
Deprecated: Use ReplaceDocumentReq_ReplaceDocumentMetadata.ProtoReflect.Descriptor instead.
func (*ReplaceDocumentReq_ReplaceDocumentMetadata) GetDocumentId ¶
func (x *ReplaceDocumentReq_ReplaceDocumentMetadata) GetDocumentId() *v1.UUID
func (*ReplaceDocumentReq_ReplaceDocumentMetadata) GetShelfId ¶
func (x *ReplaceDocumentReq_ReplaceDocumentMetadata) GetShelfId() *v1.UUID
func (*ReplaceDocumentReq_ReplaceDocumentMetadata) ProtoMessage ¶
func (*ReplaceDocumentReq_ReplaceDocumentMetadata) ProtoMessage()
func (*ReplaceDocumentReq_ReplaceDocumentMetadata) ProtoReflect ¶
func (x *ReplaceDocumentReq_ReplaceDocumentMetadata) ProtoReflect() protoreflect.Message
func (*ReplaceDocumentReq_ReplaceDocumentMetadata) Reset ¶
func (x *ReplaceDocumentReq_ReplaceDocumentMetadata) Reset()
func (*ReplaceDocumentReq_ReplaceDocumentMetadata) String ¶
func (x *ReplaceDocumentReq_ReplaceDocumentMetadata) String() string
type ReplaceImageReq ¶
type ReplaceImageReq struct {
// Types that are assignable to ReplaceData:
// *ReplaceImageReq_Metadata
// *ReplaceImageReq_Chunk
ReplaceData isReplaceImageReq_ReplaceData `protobuf_oneof:"replace_data"`
// contains filtered or unexported fields
}
func (*ReplaceImageReq) Descriptor
deprecated
func (*ReplaceImageReq) Descriptor() ([]byte, []int)
Deprecated: Use ReplaceImageReq.ProtoReflect.Descriptor instead.
func (*ReplaceImageReq) GetChunk ¶
func (x *ReplaceImageReq) GetChunk() []byte
func (*ReplaceImageReq) GetMetadata ¶
func (x *ReplaceImageReq) GetMetadata() *ReplaceImageReq_ReplaceImageMetadata
func (*ReplaceImageReq) GetReplaceData ¶
func (m *ReplaceImageReq) GetReplaceData() isReplaceImageReq_ReplaceData
func (*ReplaceImageReq) ProtoMessage ¶
func (*ReplaceImageReq) ProtoMessage()
func (*ReplaceImageReq) ProtoReflect ¶
func (x *ReplaceImageReq) ProtoReflect() protoreflect.Message
func (*ReplaceImageReq) Reset ¶
func (x *ReplaceImageReq) Reset()
func (*ReplaceImageReq) String ¶
func (x *ReplaceImageReq) String() string
type ReplaceImageReq_Chunk ¶
type ReplaceImageReq_Chunk struct {
Chunk []byte `protobuf:"bytes,2,opt,name=chunk,proto3,oneof"`
}
type ReplaceImageReq_Metadata ¶
type ReplaceImageReq_Metadata struct {
Metadata *ReplaceImageReq_ReplaceImageMetadata `protobuf:"bytes,1,opt,name=metadata,proto3,oneof"`
}
type ReplaceImageReq_ReplaceImageMetadata ¶
type ReplaceImageReq_ReplaceImageMetadata struct {
GalleryId *v1.UUID `protobuf:"bytes,1,opt,name=galleryId,proto3" json:"galleryId,omitempty"`
StackId *v1.UUID `protobuf:"bytes,2,opt,name=stackId,proto3" json:"stackId,omitempty"`
// contains filtered or unexported fields
}
func (*ReplaceImageReq_ReplaceImageMetadata) Descriptor
deprecated
func (*ReplaceImageReq_ReplaceImageMetadata) Descriptor() ([]byte, []int)
Deprecated: Use ReplaceImageReq_ReplaceImageMetadata.ProtoReflect.Descriptor instead.
func (*ReplaceImageReq_ReplaceImageMetadata) GetGalleryId ¶
func (x *ReplaceImageReq_ReplaceImageMetadata) GetGalleryId() *v1.UUID
func (*ReplaceImageReq_ReplaceImageMetadata) GetStackId ¶
func (x *ReplaceImageReq_ReplaceImageMetadata) GetStackId() *v1.UUID
func (*ReplaceImageReq_ReplaceImageMetadata) ProtoMessage ¶
func (*ReplaceImageReq_ReplaceImageMetadata) ProtoMessage()
func (*ReplaceImageReq_ReplaceImageMetadata) ProtoReflect ¶
func (x *ReplaceImageReq_ReplaceImageMetadata) ProtoReflect() protoreflect.Message
func (*ReplaceImageReq_ReplaceImageMetadata) Reset ¶
func (x *ReplaceImageReq_ReplaceImageMetadata) Reset()
func (*ReplaceImageReq_ReplaceImageMetadata) String ¶
func (x *ReplaceImageReq_ReplaceImageMetadata) String() string
type Shelf ¶
type Shelf struct {
Id *v1.UUID `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
Documents []*ShelfDocument `protobuf:"bytes,3,rep,name=documents,proto3" json:"documents,omitempty"`
// contains filtered or unexported fields
}
func (*Shelf) Descriptor
deprecated
func (*Shelf) GetDocuments ¶
func (x *Shelf) GetDocuments() []*ShelfDocument
func (*Shelf) ProtoMessage ¶
func (*Shelf) ProtoMessage()
func (*Shelf) ProtoReflect ¶
func (x *Shelf) ProtoReflect() protoreflect.Message
type ShelfDocument ¶
type ShelfDocument struct {
Document *StorageDocument `protobuf:"bytes,1,opt,name=document,proto3" json:"document,omitempty"`
Id *v1.UUID `protobuf:"bytes,2,opt,name=id,proto3" json:"id,omitempty"`
UniqueName string `protobuf:"bytes,3,opt,name=uniqueName,proto3" json:"uniqueName,omitempty"`
// contains filtered or unexported fields
}
func (*ShelfDocument) Descriptor
deprecated
func (*ShelfDocument) Descriptor() ([]byte, []int)
Deprecated: Use ShelfDocument.ProtoReflect.Descriptor instead.
func (*ShelfDocument) GetDocument ¶
func (x *ShelfDocument) GetDocument() *StorageDocument
func (*ShelfDocument) GetId ¶
func (x *ShelfDocument) GetId() *v1.UUID
func (*ShelfDocument) GetUniqueName ¶
func (x *ShelfDocument) GetUniqueName() string
func (*ShelfDocument) ProtoMessage ¶
func (*ShelfDocument) ProtoMessage()
func (*ShelfDocument) ProtoReflect ¶
func (x *ShelfDocument) ProtoReflect() protoreflect.Message
func (*ShelfDocument) Reset ¶
func (x *ShelfDocument) Reset()
func (*ShelfDocument) String ¶
func (x *ShelfDocument) String() string
type SortGalleryReq ¶
type SortGalleryReq struct {
Id *v1.UUID `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
Sorting []*v1.UUID `protobuf:"bytes,2,rep,name=sorting,proto3" json:"sorting,omitempty"`
// contains filtered or unexported fields
}
func (*SortGalleryReq) Descriptor
deprecated
func (*SortGalleryReq) Descriptor() ([]byte, []int)
Deprecated: Use SortGalleryReq.ProtoReflect.Descriptor instead.
func (*SortGalleryReq) GetId ¶
func (x *SortGalleryReq) GetId() *v1.UUID
func (*SortGalleryReq) GetSorting ¶
func (x *SortGalleryReq) GetSorting() []*v1.UUID
func (*SortGalleryReq) ProtoMessage ¶
func (*SortGalleryReq) ProtoMessage()
func (*SortGalleryReq) ProtoReflect ¶
func (x *SortGalleryReq) ProtoReflect() protoreflect.Message
func (*SortGalleryReq) Reset ¶
func (x *SortGalleryReq) Reset()
func (*SortGalleryReq) String ¶
func (x *SortGalleryReq) String() string
type Stack ¶
type Stack struct {
Id *v1.UUID `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
Images []*StackImage `protobuf:"bytes,2,rep,name=images,proto3" json:"images,omitempty"`
// contains filtered or unexported fields
}
func (*Stack) Descriptor
deprecated
func (*Stack) GetImages ¶
func (x *Stack) GetImages() []*StackImage
func (*Stack) ProtoMessage ¶
func (*Stack) ProtoMessage()
func (*Stack) ProtoReflect ¶
func (x *Stack) ProtoReflect() protoreflect.Message
type StackImage ¶
type StackImage struct {
Image *StorageImage `protobuf:"bytes,1,opt,name=image,proto3" json:"image,omitempty"`
Original bool `protobuf:"varint,2,opt,name=original,proto3" json:"original,omitempty"`
Size string `protobuf:"bytes,3,opt,name=size,proto3" json:"size,omitempty"`
// contains filtered or unexported fields
}
func (*StackImage) Descriptor
deprecated
func (*StackImage) Descriptor() ([]byte, []int)
Deprecated: Use StackImage.ProtoReflect.Descriptor instead.
func (*StackImage) GetImage ¶
func (x *StackImage) GetImage() *StorageImage
func (*StackImage) GetOriginal ¶
func (x *StackImage) GetOriginal() bool
func (*StackImage) GetSize ¶
func (x *StackImage) GetSize() string
func (*StackImage) ProtoMessage ¶
func (*StackImage) ProtoMessage()
func (*StackImage) ProtoReflect ¶
func (x *StackImage) ProtoReflect() protoreflect.Message
func (*StackImage) Reset ¶
func (x *StackImage) Reset()
func (*StackImage) String ¶
func (x *StackImage) String() string
type StorageDocument ¶
type StorageDocument struct {
File *StorageFile `protobuf:"bytes,1,opt,name=file,proto3" json:"file,omitempty"`
// contains filtered or unexported fields
}
func (*StorageDocument) Descriptor
deprecated
func (*StorageDocument) Descriptor() ([]byte, []int)
Deprecated: Use StorageDocument.ProtoReflect.Descriptor instead.
func (*StorageDocument) GetFile ¶
func (x *StorageDocument) GetFile() *StorageFile
func (*StorageDocument) ProtoMessage ¶
func (*StorageDocument) ProtoMessage()
func (*StorageDocument) ProtoReflect ¶
func (x *StorageDocument) ProtoReflect() protoreflect.Message
func (*StorageDocument) Reset ¶
func (x *StorageDocument) Reset()
func (*StorageDocument) String ¶
func (x *StorageDocument) String() string
type StorageFile ¶
type StorageFile struct {
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
Disk string `protobuf:"bytes,2,opt,name=disk,proto3" json:"disk,omitempty"`
Path string `protobuf:"bytes,3,opt,name=path,proto3" json:"path,omitempty"`
Filesize int64 `protobuf:"varint,4,opt,name=filesize,proto3" json:"filesize,omitempty"`
Tags []string `protobuf:"bytes,5,rep,name=tags,proto3" json:"tags,omitempty"`
// contains filtered or unexported fields
}
func (*StorageFile) Descriptor
deprecated
func (*StorageFile) Descriptor() ([]byte, []int)
Deprecated: Use StorageFile.ProtoReflect.Descriptor instead.
func (*StorageFile) GetDisk ¶
func (x *StorageFile) GetDisk() string
func (*StorageFile) GetFilesize ¶
func (x *StorageFile) GetFilesize() int64
func (*StorageFile) GetName ¶
func (x *StorageFile) GetName() string
func (*StorageFile) GetPath ¶
func (x *StorageFile) GetPath() string
func (*StorageFile) GetTags ¶
func (x *StorageFile) GetTags() []string
func (*StorageFile) ProtoMessage ¶
func (*StorageFile) ProtoMessage()
func (*StorageFile) ProtoReflect ¶
func (x *StorageFile) ProtoReflect() protoreflect.Message
func (*StorageFile) Reset ¶
func (x *StorageFile) Reset()
func (*StorageFile) String ¶
func (x *StorageFile) String() string
type StorageImage ¶
type StorageImage struct {
File *StorageFile `protobuf:"bytes,1,opt,name=file,proto3" json:"file,omitempty"`
Width int64 `protobuf:"varint,2,opt,name=width,proto3" json:"width,omitempty"`
Height int64 `protobuf:"varint,3,opt,name=height,proto3" json:"height,omitempty"`
// contains filtered or unexported fields
}
func (*StorageImage) Descriptor
deprecated
func (*StorageImage) Descriptor() ([]byte, []int)
Deprecated: Use StorageImage.ProtoReflect.Descriptor instead.
func (*StorageImage) GetFile ¶
func (x *StorageImage) GetFile() *StorageFile
func (*StorageImage) GetHeight ¶
func (x *StorageImage) GetHeight() int64
func (*StorageImage) GetWidth ¶
func (x *StorageImage) GetWidth() int64
func (*StorageImage) ProtoMessage ¶
func (*StorageImage) ProtoMessage()
func (*StorageImage) ProtoReflect ¶
func (x *StorageImage) ProtoReflect() protoreflect.Message
func (*StorageImage) Reset ¶
func (x *StorageImage) Reset()
func (*StorageImage) String ¶
func (x *StorageImage) String() string
type UnimplementedMediaServiceServer ¶
type UnimplementedMediaServiceServer struct {
}
UnimplementedMediaServiceServer must be embedded to have forward compatible implementations.
func (UnimplementedMediaServiceServer) FetchGallery ¶
func (UnimplementedMediaServiceServer) FetchShelf ¶
func (UnimplementedMediaServiceServer) LookupGalleryByName ¶
func (UnimplementedMediaServiceServer) LookupGalleryByName(context.Context, *v1.NameLookup) (*v1.LookupResp, error)
func (UnimplementedMediaServiceServer) LookupGalleryStackByName ¶
func (UnimplementedMediaServiceServer) LookupGalleryStackByName(context.Context, *LookupGalleryStackByNameReq) (*v1.LookupResp, error)
func (UnimplementedMediaServiceServer) LookupShelfByName ¶
func (UnimplementedMediaServiceServer) LookupShelfByName(context.Context, *v1.NameLookup) (*v1.LookupResp, error)
func (UnimplementedMediaServiceServer) ReplaceDocument ¶
func (UnimplementedMediaServiceServer) ReplaceDocument(MediaService_ReplaceDocumentServer) error
func (UnimplementedMediaServiceServer) ReplaceImage ¶
func (UnimplementedMediaServiceServer) ReplaceImage(MediaService_ReplaceImageServer) error
func (UnimplementedMediaServiceServer) SortGallery ¶
func (UnimplementedMediaServiceServer) SortGallery(context.Context, *SortGalleryReq) (*emptypb.Empty, error)
func (UnimplementedMediaServiceServer) UploadDocument ¶
func (UnimplementedMediaServiceServer) UploadDocument(MediaService_UploadDocumentServer) error
func (UnimplementedMediaServiceServer) UploadImage ¶
func (UnimplementedMediaServiceServer) UploadImage(MediaService_UploadImageServer) error
type UnsafeMediaServiceServer ¶
type UnsafeMediaServiceServer interface {
// contains filtered or unexported methods
}
UnsafeMediaServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to MediaServiceServer will result in compilation errors.
type UploadDocumentReq ¶
type UploadDocumentReq struct {
// Types that are assignable to UploadData:
// *UploadDocumentReq_Metadata
// *UploadDocumentReq_Chunk
UploadData isUploadDocumentReq_UploadData `protobuf_oneof:"upload_data"`
// contains filtered or unexported fields
}
func (*UploadDocumentReq) Descriptor
deprecated
func (*UploadDocumentReq) Descriptor() ([]byte, []int)
Deprecated: Use UploadDocumentReq.ProtoReflect.Descriptor instead.
func (*UploadDocumentReq) GetChunk ¶
func (x *UploadDocumentReq) GetChunk() []byte
func (*UploadDocumentReq) GetMetadata ¶
func (x *UploadDocumentReq) GetMetadata() *UploadDocumentReq_UploadDocumentMetadata
func (*UploadDocumentReq) GetUploadData ¶
func (m *UploadDocumentReq) GetUploadData() isUploadDocumentReq_UploadData
func (*UploadDocumentReq) ProtoMessage ¶
func (*UploadDocumentReq) ProtoMessage()
func (*UploadDocumentReq) ProtoReflect ¶
func (x *UploadDocumentReq) ProtoReflect() protoreflect.Message
func (*UploadDocumentReq) Reset ¶
func (x *UploadDocumentReq) Reset()
func (*UploadDocumentReq) String ¶
func (x *UploadDocumentReq) String() string
type UploadDocumentReq_Chunk ¶
type UploadDocumentReq_Chunk struct {
Chunk []byte `protobuf:"bytes,2,opt,name=chunk,proto3,oneof"`
}
type UploadDocumentReq_Metadata ¶
type UploadDocumentReq_Metadata struct {
Metadata *UploadDocumentReq_UploadDocumentMetadata `protobuf:"bytes,1,opt,name=metadata,proto3,oneof"`
}
type UploadDocumentReq_UploadDocumentMetadata ¶
type UploadDocumentReq_UploadDocumentMetadata struct {
ShelfId *v1.UUID `protobuf:"bytes,1,opt,name=shelfId,proto3" json:"shelfId,omitempty"`
UniqueName string `protobuf:"bytes,2,opt,name=uniqueName,proto3" json:"uniqueName,omitempty"`
Name string `protobuf:"bytes,3,opt,name=name,proto3" json:"name,omitempty"`
Disk string `protobuf:"bytes,4,opt,name=disk,proto3" json:"disk,omitempty"`
Path string `protobuf:"bytes,5,opt,name=path,proto3" json:"path,omitempty"`
// contains filtered or unexported fields
}
func (*UploadDocumentReq_UploadDocumentMetadata) Descriptor
deprecated
func (*UploadDocumentReq_UploadDocumentMetadata) Descriptor() ([]byte, []int)
Deprecated: Use UploadDocumentReq_UploadDocumentMetadata.ProtoReflect.Descriptor instead.
func (*UploadDocumentReq_UploadDocumentMetadata) GetDisk ¶
func (x *UploadDocumentReq_UploadDocumentMetadata) GetDisk() string
func (*UploadDocumentReq_UploadDocumentMetadata) GetName ¶
func (x *UploadDocumentReq_UploadDocumentMetadata) GetName() string
func (*UploadDocumentReq_UploadDocumentMetadata) GetPath ¶
func (x *UploadDocumentReq_UploadDocumentMetadata) GetPath() string
func (*UploadDocumentReq_UploadDocumentMetadata) GetShelfId ¶
func (x *UploadDocumentReq_UploadDocumentMetadata) GetShelfId() *v1.UUID
func (*UploadDocumentReq_UploadDocumentMetadata) GetUniqueName ¶
func (x *UploadDocumentReq_UploadDocumentMetadata) GetUniqueName() string
func (*UploadDocumentReq_UploadDocumentMetadata) ProtoMessage ¶
func (*UploadDocumentReq_UploadDocumentMetadata) ProtoMessage()
func (*UploadDocumentReq_UploadDocumentMetadata) ProtoReflect ¶
func (x *UploadDocumentReq_UploadDocumentMetadata) ProtoReflect() protoreflect.Message
func (*UploadDocumentReq_UploadDocumentMetadata) Reset ¶
func (x *UploadDocumentReq_UploadDocumentMetadata) Reset()
func (*UploadDocumentReq_UploadDocumentMetadata) String ¶
func (x *UploadDocumentReq_UploadDocumentMetadata) String() string
type UploadImageReq ¶
type UploadImageReq struct {
// Types that are assignable to UploadData:
// *UploadImageReq_Metadata
// *UploadImageReq_Chunk
UploadData isUploadImageReq_UploadData `protobuf_oneof:"upload_data"`
// contains filtered or unexported fields
}
func (*UploadImageReq) Descriptor
deprecated
func (*UploadImageReq) Descriptor() ([]byte, []int)
Deprecated: Use UploadImageReq.ProtoReflect.Descriptor instead.
func (*UploadImageReq) GetChunk ¶
func (x *UploadImageReq) GetChunk() []byte
func (*UploadImageReq) GetMetadata ¶
func (x *UploadImageReq) GetMetadata() *UploadImageReq_UploadImageMetadata
func (*UploadImageReq) GetUploadData ¶
func (m *UploadImageReq) GetUploadData() isUploadImageReq_UploadData
func (*UploadImageReq) ProtoMessage ¶
func (*UploadImageReq) ProtoMessage()
func (*UploadImageReq) ProtoReflect ¶
func (x *UploadImageReq) ProtoReflect() protoreflect.Message
func (*UploadImageReq) Reset ¶
func (x *UploadImageReq) Reset()
func (*UploadImageReq) String ¶
func (x *UploadImageReq) String() string
type UploadImageReq_Chunk ¶
type UploadImageReq_Chunk struct {
Chunk []byte `protobuf:"bytes,2,opt,name=chunk,proto3,oneof"`
}
type UploadImageReq_Metadata ¶
type UploadImageReq_Metadata struct {
Metadata *UploadImageReq_UploadImageMetadata `protobuf:"bytes,1,opt,name=metadata,proto3,oneof"`
}
type UploadImageReq_UploadImageMetadata ¶
type UploadImageReq_UploadImageMetadata struct {
GalleryId *v1.UUID `protobuf:"bytes,1,opt,name=galleryId,proto3" json:"galleryId,omitempty"`
Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
Disk string `protobuf:"bytes,3,opt,name=disk,proto3" json:"disk,omitempty"`
Path string `protobuf:"bytes,4,opt,name=path,proto3" json:"path,omitempty"`
// contains filtered or unexported fields
}
func (*UploadImageReq_UploadImageMetadata) Descriptor
deprecated
func (*UploadImageReq_UploadImageMetadata) Descriptor() ([]byte, []int)
Deprecated: Use UploadImageReq_UploadImageMetadata.ProtoReflect.Descriptor instead.
func (*UploadImageReq_UploadImageMetadata) GetDisk ¶
func (x *UploadImageReq_UploadImageMetadata) GetDisk() string
func (*UploadImageReq_UploadImageMetadata) GetGalleryId ¶
func (x *UploadImageReq_UploadImageMetadata) GetGalleryId() *v1.UUID
func (*UploadImageReq_UploadImageMetadata) GetName ¶
func (x *UploadImageReq_UploadImageMetadata) GetName() string
func (*UploadImageReq_UploadImageMetadata) GetPath ¶
func (x *UploadImageReq_UploadImageMetadata) GetPath() string
func (*UploadImageReq_UploadImageMetadata) ProtoMessage ¶
func (*UploadImageReq_UploadImageMetadata) ProtoMessage()
func (*UploadImageReq_UploadImageMetadata) ProtoReflect ¶
func (x *UploadImageReq_UploadImageMetadata) ProtoReflect() protoreflect.Message
func (*UploadImageReq_UploadImageMetadata) Reset ¶
func (x *UploadImageReq_UploadImageMetadata) Reset()
func (*UploadImageReq_UploadImageMetadata) String ¶
func (x *UploadImageReq_UploadImageMetadata) String() string